@@ -3,7 +3,8 @@ import copy
 from collections import deque
 
 from conan.internal.cache.conan_reference_layout import BasicLayout
-from conans.client.conanfile.configure import run_configure_method
+from conan.internal.methods import run_configure_method
+from conan.internal.model.recipe_ref import ref_matches
 from conans.client.graph.graph import DepsGraph, Node, CONTEXT_HOST, \
     CONTEXT_BUILD, TransitiveRequirement, RECIPE_VIRTUAL, RECIPE_EDITABLE
 from conans.client.graph.graph import RECIPE_PLATFORM
@@ -12,11 +13,11 @@ from conans.client.graph.graph_error import GraphLoopError, GraphConflictError,
 from conans.client.graph.profile_node_definer import initialize_conanfile_profile
 from conans.client.graph.provides import check_graph_provides
 from conan.errors import ConanException
-from conans.model.conan_file import ConanFile
-from conans.model.options import Options, _PackageOptions
-from conans.model.pkg_type import PackageType
-from conans.model.recipe_ref import RecipeReference, ref_matches
-from conans.model.requires import Requirement
+from conan.internal.model.conan_file import ConanFile
+from conan.internal.model.options import Options, _PackageOptions
+from conan.internal.model.pkg_type import PackageType
+from conan.api.model import RecipeReference
+from conan.internal.model.requires import Requirement
 
 
 class DepsGraphBuilder(object):
@@ -39,7 +40,9 @@ class DepsGraphBuilder(object):
         # print("Loading graph")
         dep_graph = DepsGraph()
 
-        self._prepare_node(root_node, profile_host, profile_build, Options())
+        is_test_package = getattr(root_node.conanfile, "tested_reference_str", None)
+        define_consumers = root_node.recipe == RECIPE_VIRTUAL or is_test_package
+        self._prepare_node(root_node, profile_host, profile_build, Options(), define_consumers)
         rs = self._initialize_requires(root_node, dep_graph, graph_lock, profile_build, profile_host)
         dep_graph.add_node(root_node)
 
@@ -171,8 +174,7 @@ class DepsGraphBuilder(object):
                 raise GraphConflictError(node, require, prev_node, prev_require, base_previous)
 
     @staticmethod
-    def _prepare_node(node, profile_host, profile_build, down_options):
-
+    def _prepare_node(node, profile_host, profile_build, down_options, define_consumers=False):
         # basic node configuration: calling configure() and requirements()
         conanfile, ref = node.conanfile, node.ref
 
@@ -180,10 +182,17 @@ class DepsGraphBuilder(object):
         assert isinstance(profile_options, Options), type(profile_options)
         run_configure_method(conanfile, down_options, profile_options, ref)
 
+        if define_consumers:  # Mark this requirements as the "consumers" nodes
+            tested_ref = getattr(conanfile, "tested_reference_str", None)
+            tested_ref = RecipeReference.loads(tested_ref) if tested_ref else None
+            for r in conanfile.requires.values():
+                if tested_ref is None or r.ref == tested_ref:
+                    r.is_consumer = True
+
         # Apply build_tools_requires from profile, overriding the declared ones
         profile = profile_host if node.context == CONTEXT_HOST else profile_build
         for pattern, tool_requires in profile.tool_requires.items():
-            if ref_matches(ref, pattern, is_consumer=conanfile._conan_is_consumer):
+            if ref_matches(ref, pattern, is_consumer=conanfile._conan_is_consumer):  # noqa
                 for tool_require in tool_requires:  # Do the override
                     if str(tool_require) == str(ref):  # FIXME: Ugly str comparison
                         continue  # avoid self-loop of build-requires in build context
@@ -309,6 +318,7 @@ class DepsGraphBuilder(object):
                 continue
             if pattern.channel != "*" and pattern.channel != require.ref.channel:
                 continue
+            require._required_ref = require.ref.copy()  # Save the original ref before replacing
             original_require = repr(require.ref)
             if alternative_ref.version != "*":
                 require.ref.version = alternative_ref.version
@@ -364,9 +374,7 @@ class DepsGraphBuilder(object):
 
         new_ref = layout.reference
         dep_conanfile.folders.set_base_recipe_metadata(layout.metadata())  # None for platform_xxx
-        # If the node is virtual or a test package, the require is also "root"
-        is_test_package = getattr(node.conanfile, "tested_reference_str", False)
-        if node.conanfile._conan_is_consumer and (node.recipe == RECIPE_VIRTUAL or is_test_package):
+        if getattr(require, "is_consumer", None):
             dep_conanfile._conan_is_consumer = True
         initialize_conanfile_profile(dep_conanfile, profile_build, profile_host, node.context,
                                      require.build, new_ref, parent=node.conanfile)
